@@ -16,7 +16,7 @@ class Storage(ABC):
         pass
     
     @abstractmethod
-    def update_session(self, session_id: int, session):
+    def update_session(self, username: str, session_id: int, session):
         pass
     
     @abstractmethod
